import reducer, {initialState} from './reducer';
import {
  ADD_ERROR,
  REMOVE_ERROR,
  RESET_ERRORS
} from './actions';

describe('spark reducer', () => {
  it('should return initial state', () => {
    expect(reducer(undefined, {}))
      .toMatchSnapshot();
  });

  it('should handle ADD_ERROR', () => {
    expect(reducer(initialState, {
      type: ADD_ERROR,
      payload: {
        error: {
          id: 'abc-123',
          mock: true
        }
      }
    })).toMatchSnapshot();
  });

  it('should handle REMOVE_ERROR', () => {
    const errorId = 'abc-123';
    const errorMap = new Map([[errorId, {mock: true}]]);
    const stateWithError = initialState.mergeIn(['errors'], errorMap).set('hasError', true);

    expect(reducer(stateWithError, {
      type: REMOVE_ERROR,
      payload: {
        errorId
      }
    })).toMatchSnapshot();
  });

  it('should handle RESET_ERRORS', () => {
    const errorId = 'abc-123';
    const errorMap = new Map([[errorId, {mock: true}]]);
    const stateWithError = initialState.mergeIn(['errors'], errorMap).set('hasError', true);

    expect(reducer(stateWithError, {
      type: RESET_ERRORS
    })).toMatchSnapshot();
  });
});
